==> haskell-gtk2hs-buildtools-0.13.8.3-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk2hs-buildtools.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gtk2hs-buildtools
version:              0.13.8.3
visibility:           public
id:                   gtk2hs-buildtools-0.13.8.3-KTFeQ5jgNDQ9ZkaT2NxBO6
key:                  gtk2hs-buildtools-0.13.8.3-KTFeQ5jgNDQ9ZkaT2NxBO6
license:              GPL-2.0-only
copyright:            (c) 2001-2010 The Gtk2Hs Team
maintainer:           gtk2hs-devel@lists.sourceforge.net
author:               Axel Simon, Duncan Coutts, Manuel Chakravaty
stability:            stable
homepage:             http://projects.haskell.org/gtk2hs/
synopsis:
    Tools to build the Gtk2Hs suite of User Interface libraries.

description:
    This package provides a set of helper programs necessary to
    build the Gtk2Hs suite of libraries. These tools include
    a modified c2hs binding tool that is used to generate
    FFI declarations, a tool to build a type hierarchy that
    mirrors the C type hierarchy of GObjects found in glib,
    and a generator for signal declarations that are used
    to call back from C to Haskell. These tools are not needed
    to actually run Gtk2Hs programs.

category:             Development
abi:                  275dfc941468f2804e0a98fbd2ebd189
exposed:              True
exposed-modules:      Gtk2HsC2Hs Gtk2HsSetup HookGenerator TypeGen
hidden-modules:
    Paths_gtk2hs_buildtools BaseVersion Config Errors Binary DLists
    FastMutInt FileOps FNameOps Map Position Set UNames CIO State
    StateBase StateTrans Attributes Idents NameSpaces Lexers C CAST
    CAttrs CBuiltin CLexer CNames CParser CParserMonad CPretty CTokens
    CTrav CHS CHSLexer CInfo GBMonad GenBind GenHeader C2HSState
    Switches C2HSConfig Version

import-dirs:          /usr/lib/ghc-9.0.2/site-local/gtk2hs-buildtools-0.13.8.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/gtk2hs-buildtools-0.13.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk2hs-buildtools
hs-libraries:         HSgtk2hs-buildtools-0.13.8.3-KTFeQ5jgNDQ9ZkaT2NxBO6
depends:
    Cabal-3.4.1.0 array-0.5.4.0 base-4.15.1.0 containers-0.6.4.1
    directory-1.3.6.2 filepath-1.4.2.1
    hashtables-1.3.1-A0HcH3ZlWaeDJDdYiwWPQa pretty-1.1.3.6
    process-1.6.13.2 random-1.2.1.1-71meI303K8iKpu6Jml2q3U

haddock-interfaces:
    /usr/share/doc/haskell-gtk2hs-buildtools/html/gtk2hs-buildtools.haddock

haddock-html:         /usr/share/doc/haskell-gtk2hs-buildtools/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gtk2hs-buildtools-0.13.8.3-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk2hs-buildtools.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gtk2hs-buildtools
version:              0.13.8.3
visibility:           public
id:                   gtk2hs-buildtools-0.13.8.3-HbORNtxWilFFJKtBZ1KqsC
key:                  gtk2hs-buildtools-0.13.8.3-HbORNtxWilFFJKtBZ1KqsC
license:              GPL-2.0-only
copyright:            (c) 2001-2010 The Gtk2Hs Team
maintainer:           gtk2hs-devel@lists.sourceforge.net
author:               Axel Simon, Duncan Coutts, Manuel Chakravaty
stability:            stable
homepage:             http://projects.haskell.org/gtk2hs/
synopsis:
    Tools to build the Gtk2Hs suite of User Interface libraries.

description:
    This package provides a set of helper programs necessary to
    build the Gtk2Hs suite of libraries. These tools include
    a modified c2hs binding tool that is used to generate
    FFI declarations, a tool to build a type hierarchy that
    mirrors the C type hierarchy of GObjects found in glib,
    and a generator for signal declarations that are used
    to call back from C to Haskell. These tools are not needed
    to actually run Gtk2Hs programs.

category:             Development
abi:                  b6ca6cc9938d11c3cb95abc8636cd8be
exposed:              True
exposed-modules:      Gtk2HsC2Hs Gtk2HsSetup HookGenerator TypeGen
hidden-modules:
    Paths_gtk2hs_buildtools BaseVersion Config Errors Binary DLists
    FastMutInt FileOps FNameOps Map Position Set UNames CIO State
    StateBase StateTrans Attributes Idents NameSpaces Lexers C CAST
    CAttrs CBuiltin CLexer CNames CParser CParserMonad CPretty CTokens
    CTrav CHS CHSLexer CInfo GBMonad GenBind GenHeader C2HSState
    Switches C2HSConfig Version

import-dirs:          /usr/lib/ghc-9.0.2/site-local/gtk2hs-buildtools-0.13.8.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/gtk2hs-buildtools-0.13.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk2hs-buildtools
hs-libraries:         HSgtk2hs-buildtools-0.13.8.3-HbORNtxWilFFJKtBZ1KqsC
depends:
    Cabal-3.4.1.0 array-0.5.4.0 base-4.15.1.0 containers-0.6.4.1
    directory-1.3.6.2 filepath-1.4.2.1
    hashtables-1.3.1-3JZ8y6g6bqi8kY62Grlvuh pretty-1.1.3.6
    process-1.6.13.2 random-1.2.1.1-8t6Qrrs5ZeF1jN6oGG3D31

haddock-interfaces:
    /usr/share/doc/haskell-gtk2hs-buildtools/html/gtk2hs-buildtools.haddock

haddock-html:         /usr/share/doc/haskell-gtk2hs-buildtools/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
